@@ -32,15 +32,6 @@ WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 POSSIBILITY OF SUCH DAMAGE.
 """
 
-__version__ = '0.2'
+__version__ = '0.3'
 __project_name__ = 'PushbulletPythonLibrary'
-__project_link__ = 'https://github.com/myles/pushbullet'
-
-from .pushbullet import Pushbullet
-
-__all__ = [
-	"Pushbullet",
-	"__version__",
-	"__project_name__",
-	"__project_link__"
-]
\ No newline at end of file
+__project_link__ = 'https://github.com/myles/pushbullet'
\ No newline at end of file
